<?xml version="1.0" ?><!DOCTYPE TS><TS language="sv" version="2.0">
<context>
    <name>AboutDialog</name>
    <message>
        <source>About KeePassX</source>
        <translation>Om KeePassX</translation>
    </message>
    <message>
        <source>KeePassX is distributed under the term of the GNU General Public License (GPL) version 2 or (at your option) version 3.</source>
        <translation>Keepassx distribueras enligt villkoren i GNU General Public License (GPL) version 2 eller (om du vill) version 3.</translation>
    </message>
    <message>
        <source>Revision</source>
        <translation>Revision</translation>
    </message>
    <message>
        <source>Using:</source>
        <translation>Använder:</translation>
    </message>
</context>
<context>
    <name>AutoType</name>
    <message>
        <source>Auto-Type - KeePassX</source>
        <translation>Auto-skriv - KeePassX</translation>
    </message>
    <message>
        <source>Couldn&apos;t find an entry that matches the window title:</source>
        <translation>Kunde inte hitta en post som matchar fönstertiteln:</translation>
    </message>
</context>
<context>
    <name>AutoTypeAssociationsModel</name>
    <message>
        <source>Window</source>
        <translation>Fönster</translation>
    </message>
    <message>
        <source>Sequence</source>
        <translation>Sekvens</translation>
    </message>
    <message>
        <source>Default sequence</source>
        <translation>Standard sekvens</translation>
    </message>
</context>
<context>
    <name>AutoTypeSelectDialog</name>
    <message>
        <source>Auto-Type - KeePassX</source>
        <translation>Auto-skriv - KeePassX</translation>
    </message>
    <message>
        <source>Select entry to Auto-Type:</source>
        <translation>Välj post att auto-skriva</translation>
    </message>
</context>
<context>
    <name>ChangeMasterKeyWidget</name>
    <message>
        <source>Password</source>
        <translation>Lösenord</translation>
    </message>
    <message>
        <source>Enter password:</source>
        <translation>Ange lösenord:</translation>
    </message>
    <message>
        <source>Repeat password:</source>
        <translation>Repetera lösenord:</translation>
    </message>
    <message>
        <source>Key file</source>
        <translation>Nyckel-fil</translation>
    </message>
    <message>
        <source>Browse</source>
        <translation>Bläddra</translation>
    </message>
    <message>
        <source>Create</source>
        <translation>Skapa</translation>
    </message>
    <message>
        <source>Key files</source>
        <translation>Nyckel-filer</translation>
    </message>
    <message>
        <source>All files</source>
        <translation>Alla filer</translation>
    </message>
    <message>
        <source>Create Key File...</source>
        <translation>Skapa nyckel-fil...</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Fel</translation>
    </message>
    <message>
        <source>Unable to create Key File : </source>
        <translation>Kunde inte skapa nyckel-fil</translation>
    </message>
    <message>
        <source>Select a key file</source>
        <translation>Välj nyckel-fil</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Fråga</translation>
    </message>
    <message>
        <source>Do you really want to use an empty string as password?</source>
        <translation>Vill du verkligen vill använda en tom sträng som lösenord?</translation>
    </message>
    <message>
        <source>Different passwords supplied.</source>
        <translation>Olika lösenord angivna</translation>
    </message>
    <message>
        <source>Failed to set key file</source>
        <translation>Kunde inte sätta nyckel-fil</translation>
    </message>
    <message>
        <source>Failed to set %1 as the Key file:
%2</source>
        <translation>Kunde inte sätta %1 som nyckel-fil:
%2</translation>
    </message>
</context>
<context>
    <name>DatabaseOpenWidget</name>
    <message>
        <source>Enter master key</source>
        <translation>Ange huvud lösenord</translation>
    </message>
    <message>
        <source>Key File:</source>
        <translation>Nyckel-fil:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Lösenord:</translation>
    </message>
    <message>
        <source>Browse</source>
        <translation>Bläddra</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Fel</translation>
    </message>
    <message>
        <source>Unable to open the database.</source>
        <translation>Kunde inte öppna databas.</translation>
    </message>
    <message>
        <source>Can&apos;t open key file</source>
        <translation>Kan inte öppna nyckel-fil</translation>
    </message>
    <message>
        <source>All files</source>
        <translation>Alla filer</translation>
    </message>
    <message>
        <source>Key files</source>
        <translation>Nyckel-filer</translation>
    </message>
    <message>
        <source>Select key file</source>
        <translation>Välj nyckel-fil</translation>
    </message>
</context>
<context>
    <name>DatabaseRepairWidget</name>
    <message>
        <source>Repair database</source>
        <translation>Laga databasen</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Fel</translation>
    </message>
    <message>
        <source>Can&apos;t open key file</source>
        <translation>Kan inte öppna nyckelfilen</translation>
    </message>
    <message>
        <source>Database opened fine. Nothing to do.</source>
        <translation>Databas öppnades fint. Inget att göra.</translation>
    </message>
    <message>
        <source>Unable to open the database.</source>
        <translation>Misslyckades att öppna databasen.</translation>
    </message>
    <message>
        <source>Success</source>
        <translation>Succé</translation>
    </message>
    <message>
        <source>The database has been successfully repaired
You can now save it.</source>
        <translation>Databasens reparation har varit lyckad.
Du kan nu spara den.</translation>
    </message>
    <message>
        <source>Unable to repair the database.</source>
        <translation>Misslyckades med att laga databasen.</translation>
    </message>
</context>
<context>
    <name>DatabaseSettingsWidget</name>
    <message>
        <source>Database name:</source>
        <translation>Databasnamn:</translation>
    </message>
    <message>
        <source>Database description:</source>
        <translation>Databasbeskrivning:</translation>
    </message>
    <message>
        <source>Transform rounds:</source>
        <translation>Transformerings varv:</translation>
    </message>
    <message>
        <source>Default username:</source>
        <translation>Standard användarnamn:</translation>
    </message>
    <message>
        <source>Use recycle bin:</source>
        <translation>Använd papperskorg:</translation>
    </message>
    <message>
        <source> MiB</source>
        <translation>MiB</translation>
    </message>
    <message>
        <source>Benchmark</source>
        <translation>Benchmark</translation>
    </message>
    <message>
        <source>Max. history items:</source>
        <translation>Maxantal historik poster:</translation>
    </message>
    <message>
        <source>Max. history size:</source>
        <translation>Maximal historik storlek:</translation>
    </message>
</context>
<context>
    <name>DatabaseTabWidget</name>
    <message>
        <source>Root</source>
        <translation>Root</translation>
    </message>
    <message>
        <source>KeePass 2 Database</source>
        <translation>KeePass 2 Databas</translation>
    </message>
    <message>
        <source>All files</source>
        <translation>Alla filer</translation>
    </message>
    <message>
        <source>Open database</source>
        <translation>Öppna databas</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Varning</translation>
    </message>
    <message>
        <source>File not found!</source>
        <translation>Filen kunde inte hittas!</translation>
    </message>
    <message>
        <source>Open KeePass 1 database</source>
        <translation>Öppna KeePass 1 databas</translation>
    </message>
    <message>
        <source>KeePass 1 database</source>
        <translation>KeePass 1 databas</translation>
    </message>
    <message>
        <source>All files (*)</source>
        <translation>Alla filer (*)</translation>
    </message>
    <message>
        <source>Close?</source>
        <translation>Stäng?</translation>
    </message>
    <message>
        <source>Save changes?</source>
        <translation>Spara ändringar?</translation>
    </message>
    <message>
        <source>&quot;%1&quot; was modified.
Save changes?</source>
        <translation>&quot;%1&quot; har ändrats.
Spara ändringarna?</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Fel</translation>
    </message>
    <message>
        <source>Writing the database failed.</source>
        <translation>Kunde inte skriva till databasen.</translation>
    </message>
    <message>
        <source>Save database as</source>
        <translation>Spara databas som</translation>
    </message>
    <message>
        <source>New database</source>
        <translation>Ny databas</translation>
    </message>
    <message>
        <source>locked</source>
        <translation>låst</translation>
    </message>
    <message>
        <source>The database you are trying to open is locked by another instance of KeePassX.
Do you want to open it anyway? Alternatively the database is opened read-only.</source>
        <translation>Databasen som du försöker öppna är låst av en annan instans av KeePassX.
Vill du öppna den ändå? Databasen kommer då att öppnas skrivskyddad.</translation>
    </message>
    <message>
        <source>Lock database</source>
        <translation>Lås databasen</translation>
    </message>
    <message>
        <source>Can't lock the database as you are currently editing it.
Please press cancel to finish your changes or discard them.</source>
        <translation>Kan inte låsa databasen eftersom du håller på att redigera den.
Tryck avbryt för att ansluta dina ändringar alternativt kasta dem.</translation>
    </message>
    <message>
        <source>This database has never been saved.
You can save the database or stop locking it.</source>
        <translation>Databasen has aldrig sparats.
Spara databasen eller sluta lås den.</translation>
    </message>
    <message>
        <source>This database has been modified.
Do you want to save the database before locking it?
Otherwise your changes are lost.</source>
        <translation>Databasen har ändrats.
Vill du spara databasen innen du låser den?
I annat fall försvinner ändringarna.</translation>
    </message>
    <message>
        <source>&quot;%1&quot; is in edit mode.
Discard changes and close anyway?</source>
        <translation>&quot;%1&quot; är i redigeringsläge.
Kasta ändringarna och stäng endå?</translation>
    </message>
    <message>
        <source>Export database to CSV file</source>
        <translation>Exportera databasen till en CSV-fil</translation>
    </message>
    <message>
        <source>CSV file</source>
        <translation>CSV-fil</translation>
    </message>
    <message>
        <source>Writing the CSV file failed.</source>
        <translation>Kunde inte skriva till CSV-filen</translation>
    </message>
    <message>
        <source>The database you are trying to save as is locked by another instance of KeePassX.
Do you want to save it anyway?</source>
        <translation>Databasen du försöker spara som är låst av en annan instans av KeePassX.
Vill du spara endå?</translation>
    </message>
</context>
<context>
    <name>DatabaseWidget</name>
    <message>
        <source>Change master key</source>
        <translation>Ändra huvud lösenord</translation>
    </message>
    <message>
        <source>Delete entry?</source>
        <translation>Ta bort post?</translation>
    </message>
    <message>
        <source>Do you really want to delete the entry &quot;%1&quot; for good?</source>
        <translation>Vill du verkligen ta bort &quot;%1&quot; för gott?</translation>
    </message>
    <message>
        <source>Delete entries?</source>
        <translation>Ta bort poster?</translation>
    </message>
    <message>
        <source>Do you really want to delete %1 entries for good?</source>
        <translation>Vill du verkligen ta bort %1 poser för gott?</translation>
    </message>
    <message>
        <source>Move entries to recycle bin?</source>
        <translation>Lägg poster i papperskorgen?</translation>
    </message>
    <message numerus="yes">
        <source>Do you really want to move %n entry(s) to the recycle bin?</source>
        <translation><numerusform>Vill du verkligen flytta %n post till papperskorgen?</numerusform><numerusform>Vill du verkligen flytta %n poster till papperskorgen?</numerusform></translation>
    </message>
    <message>
        <source>Delete group?</source>
        <translation>Ta bort grupp?</translation>
    </message>
    <message>
        <source>Do you really want to delete the group &quot;%1&quot; for good?</source>
        <translation>Vill du verkligen ta bort gruppen &quot;%1&quot; för gott?</translation>
    </message>
    <message>
        <source>Current group</source>
        <translation>Nuvarande grupp</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Fel</translation>
    </message>
    <message>
        <source>Unable to calculate master key</source>
        <translation>Kunde inte räkna nu master-nyckeln</translation>
    </message>
</context>
<context>
    <name>EditEntryWidget</name>
    <message>
        <source>Entry</source>
        <translation>Post</translation>
    </message>
    <message>
        <source>Advanced</source>
        <translation>Avancerat</translation>
    </message>
    <message>
        <source>Icon</source>
        <translation>Ikon</translation>
    </message>
    <message>
        <source>Auto-Type</source>
        <translation>Auto-skriv</translation>
    </message>
    <message>
        <source>Properties</source>
        <translation>Egenskaper</translation>
    </message>
    <message>
        <source>History</source>
        <translation>Historik</translation>
    </message>
    <message>
        <source>Entry history</source>
        <translation>Posthistork</translation>
    </message>
    <message>
        <source>Add entry</source>
        <translation>Lägg till post</translation>
    </message>
    <message>
        <source>Edit entry</source>
        <translation>Ändra post</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Fel</translation>
    </message>
    <message>
        <source>Different passwords supplied.</source>
        <translation>Olika lösenord angivna</translation>
    </message>
    <message>
        <source>New attribute</source>
        <translation>Nytt attribut</translation>
    </message>
    <message>
        <source>Select file</source>
        <translation>Välj fil</translation>
    </message>
    <message>
        <source>Unable to open file</source>
        <translation>Kunde inte öppna filen.</translation>
    </message>
    <message>
        <source>Save attachment</source>
        <translation>Spara bifogad fil</translation>
    </message>
    <message>
        <source>Unable to save the attachment:
</source>
        <translation>Kunde inte spara bifogad fil:
</translation>
    </message>
    <message>
        <source>Tomorrow</source>
        <translation>Imorgon</translation>
    </message>
    <message numerus="yes">
        <source>%n week(s)</source>
        <translation><numerusform>%n vecka</numerusform><numerusform>%n veckor</numerusform></translation>
    </message>
    <message numerus="yes">
        <source>%n month(s)</source>
        <translation><numerusform>%n månad</numerusform><numerusform>%n månader</numerusform></translation>
    </message>
    <message>
        <source>1 year</source>
        <translation>1 år</translation>
    </message>
</context>
<context>
    <name>EditEntryWidgetAdvanced</name>
    <message>
        <source>Additional attributes</source>
        <translation>Ytterligare attribut</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Lägg till</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Ändra</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Ta bort</translation>
    </message>
    <message>
        <source>Attachments</source>
        <translation>Bilagor</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Spara</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Öppna</translation>
    </message>
</context>
<context>
    <name>EditEntryWidgetAutoType</name>
    <message>
        <source>Enable Auto-Type for this entry</source>
        <translation>Slå på auto-skriv för denna post</translation>
    </message>
    <message>
        <source>Inherit default Auto-Type sequence from the group</source>
        <translation>Ärv standard auto-skriv sekvens för grupp</translation>
    </message>
    <message>
        <source>Use custom Auto-Type sequence:</source>
        <translation>Använd egen auto-skriv sekvens:</translation>
    </message>
    <message>
        <source>+</source>
        <translation>+</translation>
    </message>
    <message>
        <source>-</source>
        <translation>-</translation>
    </message>
    <message>
        <source>Window title:</source>
        <translation>Fönster titel:</translation>
    </message>
    <message>
        <source>Use default sequence</source>
        <translation>Använd standard sekvens</translation>
    </message>
    <message>
        <source>Set custom sequence:</source>
        <translation>Egen sekvens:</translation>
    </message>
</context>
<context>
    <name>EditEntryWidgetHistory</name>
    <message>
        <source>Show</source>
        <translation>Visa</translation>
    </message>
    <message>
        <source>Restore</source>
        <translation>Återställ</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Ta bort</translation>
    </message>
    <message>
        <source>Delete all</source>
        <translation>Ta bort alla</translation>
    </message>
</context>
<context>
    <name>EditEntryWidgetMain</name>
    <message>
        <source>Title:</source>
        <translation>Titel:</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Användarnamn:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Lösenord:</translation>
    </message>
    <message>
        <source>Repeat:</source>
        <translation>Repetera:</translation>
    </message>
    <message>
        <source>Gen.</source>
        <translation>Gen.</translation>
    </message>
    <message>
        <source>URL:</source>
        <translation>URL:</translation>
    </message>
    <message>
        <source>Expires</source>
        <translation>Går ut</translation>
    </message>
    <message>
        <source>Presets</source>
        <translation>Förinställningar</translation>
    </message>
    <message>
        <source>Notes:</source>
        <translation>Anteckningar:</translation>
    </message>
</context>
<context>
    <name>EditGroupWidget</name>
    <message>
        <source>Group</source>
        <translation>Grupp</translation>
    </message>
    <message>
        <source>Icon</source>
        <translation>Ikon</translation>
    </message>
    <message>
        <source>Properties</source>
        <translation>Egenskaper</translation>
    </message>
    <message>
        <source>Add group</source>
        <translation>Lägg till grupp</translation>
    </message>
    <message>
        <source>Edit group</source>
        <translation>Ändra grupp</translation>
    </message>
    <message>
        <source>Enable</source>
        <translation>Slå på</translation>
    </message>
    <message>
        <source>Disable</source>
        <translation>Stäng av</translation>
    </message>
    <message>
        <source>Inherit from parent group (%1)</source>
        <translation>Ärv från förälder grupp (%1)</translation>
    </message>
</context>
<context>
    <name>EditGroupWidgetMain</name>
    <message>
        <source>Name</source>
        <translation>Namn</translation>
    </message>
    <message>
        <source>Notes</source>
        <translation>Anteckningar</translation>
    </message>
    <message>
        <source>Expires</source>
        <translation>Går ut</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Sök</translation>
    </message>
    <message>
        <source>Auto-type</source>
        <translation>Auto-skriv</translation>
    </message>
    <message>
        <source>Use default auto-type sequence of parent group</source>
        <translation>Använd standard auto-skriv sekvensen från föräldergruppen</translation>
    </message>
    <message>
        <source>Set default auto-type sequence</source>
        <translation>Ange standard auto-skriv sekvens</translation>
    </message>
</context>
<context>
    <name>EditWidgetIcons</name>
    <message>
        <source>Use default icon</source>
        <translation>Använd standard ikon</translation>
    </message>
    <message>
        <source>Use custom icon</source>
        <translation>Använd egen ikon</translation>
    </message>
    <message>
        <source>Add custom icon</source>
        <translation>Lägg till egen ikon</translation>
    </message>
    <message>
        <source>Delete custom icon</source>
        <translation>Ta bort egen ikon</translation>
    </message>
    <message>
        <source>Images</source>
        <translation>Bilder</translation>
    </message>
    <message>
        <source>All files</source>
        <translation>Alla filer</translation>
    </message>
    <message>
        <source>Select Image</source>
        <translation>Välj bild</translation>
    </message>
    <message>
        <source>Can&apos;t delete icon!</source>
        <translation>Kan inte ta bort ikon!</translation>
    </message>
    <message numerus="yes">
        <source>Can&apos;t delete icon. Still used by %n item(s).</source>
        <translation><numerusform>Kan inte ta bort ikonen. Den används fortfarande av %n post</numerusform><numerusform>Kan inte ta bort ikonen. Den används fortfarande av %n poster</numerusform></translation>
    </message>
</context>
<context>
    <name>EditWidgetProperties</name>
    <message>
        <source>Created:</source>
        <translation>Skapad:</translation>
    </message>
    <message>
        <source>Modified:</source>
        <translation>Ändrad:</translation>
    </message>
    <message>
        <source>Accessed:</source>
        <translation>Läst:</translation>
    </message>
    <message>
        <source>Uuid:</source>
        <translation>UUID:</translation>
    </message>
</context>
<context>
    <name>EntryAttributesModel</name>
    <message>
        <source>Name</source>
        <translation>Namn</translation>
    </message>
</context>
<context>
    <name>EntryHistoryModel</name>
    <message>
        <source>Last modified</source>
        <translation>Senast ändrad</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>Titel</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Användarnamn</translation>
    </message>
    <message>
        <source>URL</source>
        <translation>URL</translation>
    </message>
</context>
<context>
    <name>EntryModel</name>
    <message>
        <source>Group</source>
        <translation>Grupp</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>Titel</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Användarnamn</translation>
    </message>
    <message>
        <source>URL</source>
        <translation>URL</translation>
    </message>
</context>
<context>
    <name>Group</name>
    <message>
        <source>Recycle Bin</source>
        <translation>Papperskorg</translation>
    </message>
</context>
<context>
    <name>KeePass1OpenWidget</name>
    <message>
        <source>Import KeePass1 database</source>
        <translation>Importera KeePass1 databas</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Fel</translation>
    </message>
    <message>
        <source>Unable to open the database.</source>
        <translation>Kunde inte öppna databas.</translation>
    </message>
</context>
<context>
    <name>KeePass1Reader</name>
    <message>
        <source>Unable to read keyfile.</source>
        <translation>Kunde inte läsa nyckel-filen.</translation>
    </message>
    <message>
        <source>Not a KeePass database.</source>
        <translation>Inte en KeePass databas</translation>
    </message>
    <message>
        <source>Unsupported encryption algorithm.</source>
        <translation>Krypteringsalgoritnmen stöds ej</translation>
    </message>
    <message>
        <source>Unsupported KeePass database version.</source>
        <translation>KeePass databas versionen stöds ej.</translation>
    </message>
    <message>
        <source>Root</source>
        <translation>Root</translation>
    </message>
    <message>
        <source>Unable to calculate master key</source>
        <translation>Kunde inte räkna nu master-nyckeln</translation>
    </message>
</context>
<context>
    <name>KeePass2Reader</name>
    <message>
        <source>Not a KeePass database.</source>
        <translation>Inte en KeePass databas.</translation>
    </message>
    <message>
        <source>Unsupported KeePass database version.</source>
        <translation>KeePass databas versionen stöds ej.</translation>
    </message>
    <message>
        <source>Wrong key or database file is corrupt.</source>
        <translation>Fel lösenord eller korrupt databas-fil</translation>
    </message>
    <message>
        <source>Unable to calculate master key</source>
        <translation>Kunde inte räkna nu master-nyckeln</translation>
    </message>
    <message>
        <source>The selected file is an old KeePass 1 database (.kdb).

You can import it by clicking on Database &gt; 'Import KeePass 1 database'.
This is a one-way migration. You won&apos;t be able to open the imported database with the old KeePassX 0.4 version.</source>
        <translation>Den valda filen är en gammal KeePass 1 databas (.kdb)

Du kan importera den genom att klicka på Databas &gt; Importera KeePass 1 databas.
Detta är en envägsmigration. Du kan inte spara en databas som KeePass1 databas. Det som används i KeePassX 0.4.</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Fatal error while testing the cryptographic functions.</source>
        <translation>Allvarligt fel vid testning av kryptografiska funktioner.</translation>
    </message>
    <message>
        <source>KeePassX - Error</source>
        <translation>KeePassX - Fel</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Database</source>
        <translation>Databas</translation>
    </message>
    <message>
        <source>Recent databases</source>
        <translation>Senast använda databaser</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Hjälp</translation>
    </message>
    <message>
        <source>Entries</source>
        <translation>Poster</translation>
    </message>
    <message>
        <source>Copy attribute to clipboard</source>
        <translation>Kopiera attribut</translation>
    </message>
    <message>
        <source>Groups</source>
        <translation>Grupper</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Vy</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>Avsluta</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Om</translation>
    </message>
    <message>
        <source>Open database</source>
        <translation>Öppna databas</translation>
    </message>
    <message>
        <source>Save database</source>
        <translation>Spara databas</translation>
    </message>
    <message>
        <source>Close database</source>
        <translation>Stäng databas</translation>
    </message>
    <message>
        <source>New database</source>
        <translation>Ny databas</translation>
    </message>
    <message>
        <source>Add new entry</source>
        <translation>Lägg till ny post</translation>
    </message>
    <message>
        <source>View/Edit entry</source>
        <translation>Visa/ändra post</translation>
    </message>
    <message>
        <source>Delete entry</source>
        <translation>Ta bort post</translation>
    </message>
    <message>
        <source>Add new group</source>
        <translation>Lägg till ny grupp</translation>
    </message>
    <message>
        <source>Edit group</source>
        <translation>Ändra grupp</translation>
    </message>
    <message>
        <source>Delete group</source>
        <translation>Ta bort grupp</translation>
    </message>
    <message>
        <source>Save database as</source>
        <translation>Spara databas som</translation>
    </message>
    <message>
        <source>Change master key</source>
        <translation>Ändra huvud lösenord</translation>
    </message>
    <message>
        <source>Database settings</source>
        <translation>Databasinställningar</translation>
    </message>
    <message>
        <source>Import KeePass 1 database</source>
        <translation>Importera KeePass1 databas</translation>
    </message>
    <message>
        <source>Clone entry</source>
        <translation>Klona post</translation>
    </message>
    <message>
        <source>Find</source>
        <translation>Sök</translation>
    </message>
    <message>
        <source>Copy username to clipboard</source>
        <translation>Kopiera användarnamn</translation>
    </message>
    <message>
        <source>Copy password to clipboard</source>
        <translation>Kopiera lösenord</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Inställningar</translation>
    </message>
    <message>
        <source>Perform Auto-Type</source>
        <translation>Utför auto-skriv</translation>
    </message>
    <message>
        <source>Open URL</source>
        <translation>Öppna URL</translation>
    </message>
    <message>
        <source>Lock databases</source>
        <translation>Lås databaser</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>Titel</translation>
    </message>
    <message>
        <source>URL</source>
        <translation>URL</translation>
    </message>
    <message>
        <source>Notes</source>
        <translation>Anteckningar</translation>
    </message>
    <message>
        <source>Show toolbar</source>
        <translation>Visa verktygsfält</translation>
    </message>
    <message>
        <source>read-only</source>
        <translation>läs bara</translation>
    </message>
    <message>
        <source>Toggle window</source>
        <translation>Visa/dölj fönster</translation>
    </message>
    <message>
        <source>Tools</source>
        <translation>Verktyg</translation>
    </message>
    <message>
        <source>Copy username</source>
        <translation>Kopiera användarnamn</translation>
    </message>
    <message>
        <source>Copy password</source>
        <translation>Kopiera lösenord</translation>
    </message>
    <message>
        <source>Export to CSV file</source>
        <translation>Exportera till CSV-fil</translation>
    </message>
    <message>
        <source>Repair database</source>
        <translation>Laga databasen</translation>
    </message>
    <message>
        <source>KeePass 2 Database</source>
        <translation>KeePass 2 databas</translation>
    </message>
    <message>
        <source>All files</source>
        <translation>Alla filer</translation>
    </message>
    <message>
        <source>Save repaired database</source>
        <translation>Spara lagad databas</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Fel</translation>
    </message>
    <message>
        <source>Writing the database failed.</source>
        <translation>Misslyckades med att skriva till databasen.</translation>
    </message>
</context>
<context>
    <name>PasswordGeneratorWidget</name>
    <message>
        <source>Password:</source>
        <translation>Lösenord:</translation>
    </message>
    <message>
        <source>Length:</source>
        <translation>Längd:</translation>
    </message>
    <message>
        <source>Character Types</source>
        <translation>Teckentyper</translation>
    </message>
    <message>
        <source>Upper Case Letters</source>
        <translation>Versaler</translation>
    </message>
    <message>
        <source>Lower Case Letters</source>
        <translation>Gemener</translation>
    </message>
    <message>
        <source>Numbers</source>
        <translation>Siffror</translation>
    </message>
    <message>
        <source>Special Characters</source>
        <translation>Specialtecken</translation>
    </message>
    <message>
        <source>Exclude look-alike characters</source>
        <translation>Uteslut liknande tecken</translation>
    </message>
    <message>
        <source>Ensure that the password contains characters from every group</source>
        <translation>Säkerställ att lösenordet innehåller tecken från varje grupp</translation>
    </message>
    <message>
        <source>Accept</source>
        <translation>Acceptera</translation>
    </message>
</context>
<context>
    <name>QCommandLineParser</name>
    <message>
        <source>Displays version information.</source>
        <translation>Visar versionsinformation.</translation>
    </message>
    <message>
        <source>Displays this help.</source>
        <translation>Visa denna hjälp.</translation>
    </message>
    <message>
        <source>Unknown option &apos;%1&apos;.</source>
        <translation>Okänt alternativ: &apos;%1&apos;</translation>
    </message>
    <message>
        <source>Unknown options: %1.</source>
        <translation>Okända alternativ: &apos;%1&apos;</translation>
    </message>
    <message>
        <source>Missing value after &apos;%1&apos;.</source>
        <translation>Saknar värde efter &apos;%1&apos;</translation>
    </message>
    <message>
        <source>Unexpected value after &apos;%1&apos;.</source>
        <translation>Oväntat värde efter &apos;%1&apos;</translation>
    </message>
    <message>
        <source>[options]</source>
        <translation>[alternativ]</translation>
    </message>
    <message>
        <source>Usage: %1</source>
        <translation>Användning: %1</translation>
    </message>
    <message>
        <source>Options:</source>
        <translation>Alternativ:</translation>
    </message>
    <message>
        <source>Arguments:</source>
        <translation>Argument:</translation>
    </message>
</context>
<context>
    <name>QSaveFile</name>
    <message>
        <source>Existing file %1 is not writable</source>
        <translation>Den existerande filen %1 är inte skrivbar</translation>
    </message>
    <message>
        <source>Writing canceled by application</source>
        <translation>Skrivning avbruten av applikation</translation>
    </message>
    <message>
        <source>Partial write. Partition full?</source>
        <translation>Delvis skrivet. Är partitionen full?</translation>
    </message>
</context>
<context>
    <name>QtIOCompressor</name>
    <message>
        <source>Internal zlib error when compressing: </source>
        <translation>Internt zlib fel vid komprimering:</translation>
    </message>
    <message>
        <source>Error writing to underlying device: </source>
        <translation>Fel vid skrivning till underliggande enhet:</translation>
    </message>
    <message>
        <source>Error opening underlying device: </source>
        <translation>Fel vid öppning av underliggande enhet:</translation>
    </message>
    <message>
        <source>Error reading data from underlying device: </source>
        <translation>Fel vid läsning från underliggande enhet:</translation>
    </message>
    <message>
        <source>Internal zlib error when decompressing: </source>
        <translation>Internt zlib fel vid extrahering:</translation>
    </message>
</context>
<context>
    <name>QtIOCompressor::open</name>
    <message>
        <source>The gzip format not supported in this version of zlib.</source>
        <translation>Gzip formatet stöds inte av denna version av zlib.</translation>
    </message>
    <message>
        <source>Internal zlib error: </source>
        <translation>Internt zlib fel:</translation>
    </message>
</context>
<context>
    <name>SearchWidget</name>
    <message>
        <source>Find:</source>
        <translation>Sök:</translation>
    </message>
    <message>
        <source>Case sensitive</source>
        <translation>Skiftlägeskänslig</translation>
    </message>
    <message>
        <source>Current group</source>
        <translation>Nuvarande grupp</translation>
    </message>
    <message>
        <source>Root group</source>
        <translation>Root grupp</translation>
    </message>
</context>
<context>
    <name>SettingsWidget</name>
    <message>
        <source>Application Settings</source>
        <translation>Applikationsinställningar</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Allmän</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>Säkerhet</translation>
    </message>
</context>
<context>
    <name>SettingsWidgetGeneral</name>
    <message>
        <source>Remember last databases</source>
        <translation>Komihåg senaste databasen</translation>
    </message>
    <message>
        <source>Open previous databases on startup</source>
        <translation>Öppna senaste databasen när programmet startar</translation>
    </message>
    <message>
        <source>Automatically save on exit</source>
        <translation>Spara automatiskt när applikationen anslutas</translation>
    </message>
    <message>
        <source>Automatically save after every change</source>
        <translation>Spara automatiskt efter varje ändring</translation>
    </message>
    <message>
        <source>Minimize when copying to clipboard</source>
        <translation>Minimera vid kopiering</translation>
    </message>
    <message>
        <source>Use group icon on entry creation</source>
        <translation>Använd gruppens ikon för nya poster</translation>
    </message>
    <message>
        <source>Global Auto-Type shortcut</source>
        <translation>Globalt auto-skriv kortkommando</translation>
    </message>
    <message>
        <source>Use entry title to match windows for global auto-type</source>
        <translation>Använda postens titel till matchning med fönster för globalt auto-skriv</translation>
    </message>
    <message>
        <source>Language</source>
        <translation>Språk</translation>
    </message>
    <message>
        <source>Show a system tray icon</source>
        <translation>Visa statusfält ikon</translation>
    </message>
    <message>
        <source>Hide window to system tray when minimized</source>
        <translation>Vid minimering, minimera fönstret till systemfältet</translation>
    </message>
    <message>
        <source>Remember last key files</source>
        <translation>Komihåg senaste nyckel-filen</translation>
    </message>
</context>
<context>
    <name>SettingsWidgetSecurity</name>
    <message>
        <source>Clear clipboard after</source>
        <translation>Rensa urklipp efter</translation>
    </message>
    <message>
        <source> sec</source>
        <translation>sek</translation>
    </message>
    <message>
        <source>Lock databases after inactivity of</source>
        <translation>Lås databaser efter inaktivitet i</translation>
    </message>
    <message>
        <source>Show passwords in cleartext by default</source>
        <translation>Visa lösenord i klartext som standard</translation>
    </message>
    <message>
        <source>Always ask before performing auto-type</source>
        <translation>Fråga alltid innan auto-skriv utförs</translation>
    </message>
</context>
<context>
    <name>UnlockDatabaseWidget</name>
    <message>
        <source>Unlock database</source>
        <translation>Lås upp databas</translation>
    </message>
</context>
<context>
    <name>WelcomeWidget</name>
    <message>
        <source>Welcome!</source>
        <translation>Välkommen!</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>KeePassX - cross-platform password manager</source>
        <translation>KeePassX - plattformsoberoende lösenordshanterare</translation>
    </message>
    <message>
        <source>filename of the password database to open (*.kdbx)</source>
        <translation>namn på databas fil att öppna (*.kdbx)</translation>
    </message>
    <message>
        <source>path to a custom config file</source>
        <translation>Sökväg till egen konfigurations-fil</translation>
    </message>
    <message>
        <source>key file of the database</source>
        <translation>nyckel-fil för databas</translation>
    </message>
</context>
</TS>